========
NanoCore
========


.. image:: https://img.shields.io/pypi/v/nanocore.svg
        :target: https://pypi.python.org/pypi/nanocore

.. image:: https://img.shields.io/travis/asteriogonzalez/nanocore.svg
        :target: https://travis-ci.com/asteriogonzalez/nanocore

.. image:: https://readthedocs.org/projects/nanocore/badge/?version=latest
        :target: https://nanocore.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




A Nano Async Core


* Free software: MIT license
* Documentation: https://nanocore.readthedocs.io.


Features
----------------

* TODO

Before Coding
----------------

* create a virtual env

.. code-block:: 
  
  python3 -m venv .venv
  source .venv/bin/activate
  make install-testing-requisites

Credits
----------------

This package was created with Cookiecutter_ .

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
